Documentation
¶
Index ¶
- Variables
- type AvailabilityConfiguration
- func (*AvailabilityConfiguration) Descriptor() ([]byte, []int)deprecated
- func (x *AvailabilityConfiguration) GetAutomaticFailoverRoutingConfigured() bool
- func (x *AvailabilityConfiguration) GetAvailabilityType() AvailabilityType
- func (x *AvailabilityConfiguration) GetCrossRegionReplicaConfigured() bool
- func (x *AvailabilityConfiguration) GetExternalReplicaConfigured() bool
- func (x *AvailabilityConfiguration) GetPromotableReplicaConfigured() bool
- func (*AvailabilityConfiguration) ProtoMessage()
- func (x *AvailabilityConfiguration) ProtoReflect() protoreflect.Message
- func (x *AvailabilityConfiguration) Reset()
- func (x *AvailabilityConfiguration) String() string
- type AvailabilityType
- func (AvailabilityType) Descriptor() protoreflect.EnumDescriptor
- func (x AvailabilityType) Enum() *AvailabilityType
- func (AvailabilityType) EnumDescriptor() ([]byte, []int)deprecated
- func (x AvailabilityType) Number() protoreflect.EnumNumber
- func (x AvailabilityType) String() string
- func (AvailabilityType) Type() protoreflect.EnumType
- type BackupConfiguration
- func (*BackupConfiguration) Descriptor() ([]byte, []int)deprecated
- func (x *BackupConfiguration) GetAutomatedBackupEnabled() bool
- func (x *BackupConfiguration) GetBackupRetentionSettings() *RetentionSettings
- func (x *BackupConfiguration) GetPointInTimeRecoveryEnabled() bool
- func (*BackupConfiguration) ProtoMessage()
- func (x *BackupConfiguration) ProtoReflect() protoreflect.Message
- func (x *BackupConfiguration) Reset()
- func (x *BackupConfiguration) String() string
- type BackupRun
- func (*BackupRun) Descriptor() ([]byte, []int)deprecated
- func (x *BackupRun) GetEndTime() *timestamppb.Timestamp
- func (x *BackupRun) GetStartTime() *timestamppb.Timestamp
- func (x *BackupRun) GetStatus() BackupRun_Status
- func (*BackupRun) ProtoMessage()
- func (x *BackupRun) ProtoReflect() protoreflect.Message
- func (x *BackupRun) Reset()
- func (x *BackupRun) String() string
- type BackupRun_Status
- func (BackupRun_Status) Descriptor() protoreflect.EnumDescriptor
- func (x BackupRun_Status) Enum() *BackupRun_Status
- func (BackupRun_Status) EnumDescriptor() ([]byte, []int)deprecated
- func (x BackupRun_Status) Number() protoreflect.EnumNumber
- func (x BackupRun_Status) String() string
- func (BackupRun_Status) Type() protoreflect.EnumType
- type ConfigBasedSignalData
- func (*ConfigBasedSignalData) Descriptor() ([]byte, []int)deprecated
- func (x *ConfigBasedSignalData) GetFullResourceName() string
- func (x *ConfigBasedSignalData) GetLastRefreshTime() *timestamppb.Timestamp
- func (x *ConfigBasedSignalData) GetResourceId() *DatabaseResourceId
- func (x *ConfigBasedSignalData) GetSignalBoolValue() bool
- func (m *ConfigBasedSignalData) GetSignalMetadata() isConfigBasedSignalData_SignalMetadata
- func (x *ConfigBasedSignalData) GetSignalType() SignalType
- func (*ConfigBasedSignalData) ProtoMessage()
- func (x *ConfigBasedSignalData) ProtoReflect() protoreflect.Message
- func (x *ConfigBasedSignalData) Reset()
- func (x *ConfigBasedSignalData) String() string
- type ConfigBasedSignalData_SignalBoolValue
- type DatabaseResourceFeed
- func (*DatabaseResourceFeed) Descriptor() ([]byte, []int)deprecated
- func (x *DatabaseResourceFeed) GetConfigBasedSignalData() *ConfigBasedSignalData
- func (m *DatabaseResourceFeed) GetContent() isDatabaseResourceFeed_Content
- func (x *DatabaseResourceFeed) GetFeedTimestamp() *timestamppb.Timestamp
- func (x *DatabaseResourceFeed) GetFeedType() DatabaseResourceFeed_FeedType
- func (x *DatabaseResourceFeed) GetResourceMetadata() *DatabaseResourceMetadata
- func (*DatabaseResourceFeed) ProtoMessage()
- func (x *DatabaseResourceFeed) ProtoReflect() protoreflect.Message
- func (x *DatabaseResourceFeed) Reset()
- func (x *DatabaseResourceFeed) String() string
- type DatabaseResourceFeed_ConfigBasedSignalData
- type DatabaseResourceFeed_FeedType
- func (DatabaseResourceFeed_FeedType) Descriptor() protoreflect.EnumDescriptor
- func (x DatabaseResourceFeed_FeedType) Enum() *DatabaseResourceFeed_FeedType
- func (DatabaseResourceFeed_FeedType) EnumDescriptor() ([]byte, []int)deprecated
- func (x DatabaseResourceFeed_FeedType) Number() protoreflect.EnumNumber
- func (x DatabaseResourceFeed_FeedType) String() string
- func (DatabaseResourceFeed_FeedType) Type() protoreflect.EnumType
- type DatabaseResourceFeed_ResourceMetadata
- type DatabaseResourceId
- func (*DatabaseResourceId) Descriptor() ([]byte, []int)deprecated
- func (x *DatabaseResourceId) GetProvider() DatabaseResourceId_Provider
- func (x *DatabaseResourceId) GetProviderDescription() string
- func (x *DatabaseResourceId) GetResourceType() string
- func (x *DatabaseResourceId) GetUniqueId() string
- func (*DatabaseResourceId) ProtoMessage()
- func (x *DatabaseResourceId) ProtoReflect() protoreflect.Message
- func (x *DatabaseResourceId) Reset()
- func (x *DatabaseResourceId) String() string
- type DatabaseResourceId_Provider
- func (DatabaseResourceId_Provider) Descriptor() protoreflect.EnumDescriptor
- func (x DatabaseResourceId_Provider) Enum() *DatabaseResourceId_Provider
- func (DatabaseResourceId_Provider) EnumDescriptor() ([]byte, []int)deprecated
- func (x DatabaseResourceId_Provider) Number() protoreflect.EnumNumber
- func (x DatabaseResourceId_Provider) String() string
- func (DatabaseResourceId_Provider) Type() protoreflect.EnumType
- type DatabaseResourceMetadata
- func (*DatabaseResourceMetadata) Descriptor() ([]byte, []int)deprecated
- func (x *DatabaseResourceMetadata) GetAvailabilityConfiguration() *AvailabilityConfiguration
- func (x *DatabaseResourceMetadata) GetBackupConfiguration() *BackupConfiguration
- func (x *DatabaseResourceMetadata) GetBackupRun() *BackupRun
- func (x *DatabaseResourceMetadata) GetCreationTime() *timestamppb.Timestamp
- func (x *DatabaseResourceMetadata) GetCurrentState() DatabaseResourceMetadata_State
- func (x *DatabaseResourceMetadata) GetExpectedState() DatabaseResourceMetadata_State
- func (x *DatabaseResourceMetadata) GetId() *DatabaseResourceId
- func (x *DatabaseResourceMetadata) GetInstanceType() InstanceType
- func (x *DatabaseResourceMetadata) GetLocation() string
- func (x *DatabaseResourceMetadata) GetMachineConfiguration() *MachineConfiguration
- func (x *DatabaseResourceMetadata) GetPrimaryResourceId() *DatabaseResourceId
- func (x *DatabaseResourceMetadata) GetPrimaryResourceLocation() string
- func (x *DatabaseResourceMetadata) GetProduct() *Product
- func (x *DatabaseResourceMetadata) GetResourceContainer() string
- func (x *DatabaseResourceMetadata) GetResourceName() string
- func (x *DatabaseResourceMetadata) GetTagsSet() *Tags
- func (x *DatabaseResourceMetadata) GetUpdationTime() *timestamppb.Timestamp
- func (x *DatabaseResourceMetadata) GetUserLabelSet() *UserLabels
- func (*DatabaseResourceMetadata) ProtoMessage()
- func (x *DatabaseResourceMetadata) ProtoReflect() protoreflect.Message
- func (x *DatabaseResourceMetadata) Reset()
- func (x *DatabaseResourceMetadata) String() string
- type DatabaseResourceMetadata_State
- func (DatabaseResourceMetadata_State) Descriptor() protoreflect.EnumDescriptor
- func (x DatabaseResourceMetadata_State) Enum() *DatabaseResourceMetadata_State
- func (DatabaseResourceMetadata_State) EnumDescriptor() ([]byte, []int)deprecated
- func (x DatabaseResourceMetadata_State) Number() protoreflect.EnumNumber
- func (x DatabaseResourceMetadata_State) String() string
- func (DatabaseResourceMetadata_State) Type() protoreflect.EnumType
- type Engine
- type GCBDRConfiguration
- func (*GCBDRConfiguration) Descriptor() ([]byte, []int)deprecated
- func (x *GCBDRConfiguration) GetGcbdrManaged() bool
- func (*GCBDRConfiguration) ProtoMessage()
- func (x *GCBDRConfiguration) ProtoReflect() protoreflect.Message
- func (x *GCBDRConfiguration) Reset()
- func (x *GCBDRConfiguration) String() string
- type InstanceType
- func (InstanceType) Descriptor() protoreflect.EnumDescriptor
- func (x InstanceType) Enum() *InstanceType
- func (InstanceType) EnumDescriptor() ([]byte, []int)deprecated
- func (x InstanceType) Number() protoreflect.EnumNumber
- func (x InstanceType) String() string
- func (InstanceType) Type() protoreflect.EnumType
- type MachineConfiguration
- func (*MachineConfiguration) Descriptor() ([]byte, []int)deprecated
- func (x *MachineConfiguration) GetMemorySizeInBytes() int64
- func (x *MachineConfiguration) GetShardCount() int32
- func (x *MachineConfiguration) GetVcpuCount() float64
- func (*MachineConfiguration) ProtoMessage()
- func (x *MachineConfiguration) ProtoReflect() protoreflect.Message
- func (x *MachineConfiguration) Reset()
- func (x *MachineConfiguration) String() string
- type Product
- func (*Product) Descriptor() ([]byte, []int)deprecated
- func (x *Product) GetEngine() Engine
- func (x *Product) GetMinorVersion() string
- func (x *Product) GetType() ProductType
- func (x *Product) GetVersion() string
- func (*Product) ProtoMessage()
- func (x *Product) ProtoReflect() protoreflect.Message
- func (x *Product) Reset()
- func (x *Product) String() string
- type ProductType
- func (ProductType) Descriptor() protoreflect.EnumDescriptor
- func (x ProductType) Enum() *ProductType
- func (ProductType) EnumDescriptor() ([]byte, []int)deprecated
- func (x ProductType) Number() protoreflect.EnumNumber
- func (x ProductType) String() string
- func (ProductType) Type() protoreflect.EnumType
- type RetentionSettings
- func (*RetentionSettings) Descriptor() ([]byte, []int)deprecated
- func (x *RetentionSettings) GetDurationBasedRetention() *durationpb.Duration
- func (x *RetentionSettings) GetQuantityBasedRetention() *wrapperspb.Int32Value
- func (m *RetentionSettings) GetRetention() isRetentionSettings_Retention
- func (x *RetentionSettings) GetTimestampBasedRetentionTime() *timestamppb.Timestamp
- func (*RetentionSettings) ProtoMessage()
- func (x *RetentionSettings) ProtoReflect() protoreflect.Message
- func (x *RetentionSettings) Reset()
- func (x *RetentionSettings) String() string
- type RetentionSettings_DurationBasedRetention
- type RetentionSettings_QuantityBasedRetention
- type RetentionSettings_TimestampBasedRetentionTime
- type SignalType
- type Tags
- type UserLabels
Constants ¶
This section is empty.
Variables ¶
var ( Engine_name = map[int32]string{ 0: "ENGINE_UNSPECIFIED", 1: "ENGINE_MYSQL", 2: "ENGINE_POSTGRES", 3: "ENGINE_SQL_SERVER", 4: "ENGINE_NATIVE", 12: "ENGINE_EXADATA_ORACLE", 13: "ENGINE_ADB_SERVERLESS_ORACLE", 6: "ENGINE_OTHER", } Engine_value = map[string]int32{ "ENGINE_UNSPECIFIED": 0, "ENGINE_MYSQL": 1, "ENGINE_POSTGRES": 2, "ENGINE_SQL_SERVER": 3, "ENGINE_NATIVE": 4, "ENGINE_EXADATA_ORACLE": 12, "ENGINE_ADB_SERVERLESS_ORACLE": 13, "ENGINE_OTHER": 6, } )
Enum value maps for Engine.
var ( ProductType_name = map[int32]string{ 0: "PRODUCT_TYPE_UNSPECIFIED", 4: "PRODUCT_TYPE_ON_PREM", 5: "PRODUCT_TYPE_OTHER", 9: "PRODUCT_TYPE_COMPUTE_ENGINE", 10: "PRODUCT_TYPE_ORACLE_ON_GCP", } ProductType_value = map[string]int32{ "PRODUCT_TYPE_UNSPECIFIED": 0, "PRODUCT_TYPE_ON_PREM": 4, "PRODUCT_TYPE_OTHER": 5, "PRODUCT_TYPE_COMPUTE_ENGINE": 9, "PRODUCT_TYPE_ORACLE_ON_GCP": 10, } )
Enum value maps for ProductType.
var ( InstanceType_name = map[int32]string{ 0: "INSTANCE_TYPE_UNSPECIFIED", 9: "SUB_RESOURCE_TYPE_UNSPECIFIED", 5: "SUB_RESOURCE_TYPE_PRIMARY", 6: "SUB_RESOURCE_TYPE_SECONDARY", 7: "SUB_RESOURCE_TYPE_READ_REPLICA", 10: "SUB_RESOURCE_TYPE_EXTERNAL_PRIMARY", 8: "SUB_RESOURCE_TYPE_OTHER", } InstanceType_value = map[string]int32{ "INSTANCE_TYPE_UNSPECIFIED": 0, "SUB_RESOURCE_TYPE_UNSPECIFIED": 9, "SUB_RESOURCE_TYPE_PRIMARY": 5, "SUB_RESOURCE_TYPE_SECONDARY": 6, "SUB_RESOURCE_TYPE_READ_REPLICA": 7, "SUB_RESOURCE_TYPE_EXTERNAL_PRIMARY": 10, "SUB_RESOURCE_TYPE_OTHER": 8, } )
Enum value maps for InstanceType.
var ( AvailabilityType_name = map[int32]string{ 0: "AVAILABILITY_TYPE_UNSPECIFIED", 1: "ZONAL", 2: "REGIONAL", 3: "MULTI_REGIONAL", 4: "AVAILABILITY_TYPE_OTHER", } AvailabilityType_value = map[string]int32{ "AVAILABILITY_TYPE_UNSPECIFIED": 0, "ZONAL": 1, "REGIONAL": 2, "MULTI_REGIONAL": 3, "AVAILABILITY_TYPE_OTHER": 4, } )
Enum value maps for AvailabilityType.
var ( SignalType_name = map[int32]string{ 0: "SIGNAL_TYPE_UNSPECIFIED", 1: "SIGNAL_TYPE_OUTDATED_MINOR_VERSION", 2: "SIGNAL_TYPE_DATABASE_AUDITING_DISABLED", 3: "SIGNAL_TYPE_NO_ROOT_PASSWORD", 4: "SIGNAL_TYPE_EXPOSED_TO_PUBLIC_ACCESS", 5: "SIGNAL_TYPE_UNENCRYPTED_CONNECTIONS", } SignalType_value = map[string]int32{ "SIGNAL_TYPE_UNSPECIFIED": 0, "SIGNAL_TYPE_OUTDATED_MINOR_VERSION": 1, "SIGNAL_TYPE_DATABASE_AUDITING_DISABLED": 2, "SIGNAL_TYPE_NO_ROOT_PASSWORD": 3, "SIGNAL_TYPE_EXPOSED_TO_PUBLIC_ACCESS": 4, "SIGNAL_TYPE_UNENCRYPTED_CONNECTIONS": 5, } )
Enum value maps for SignalType.
var ( DatabaseResourceId_Provider_name = map[int32]string{ 0: "PROVIDER_UNSPECIFIED", 1: "GCP", 2: "AWS", 3: "AZURE", 4: "ONPREM", 5: "SELFMANAGED", 6: "PROVIDER_OTHER", } DatabaseResourceId_Provider_value = map[string]int32{ "PROVIDER_UNSPECIFIED": 0, "GCP": 1, "AWS": 2, "AZURE": 3, "ONPREM": 4, "SELFMANAGED": 5, "PROVIDER_OTHER": 6, } )
Enum value maps for DatabaseResourceId_Provider.
var ( DatabaseResourceFeed_FeedType_name = map[int32]string{ 0: "FEEDTYPE_UNSPECIFIED", 1: "RESOURCE_METADATA", 5: "CONFIG_BASED_SIGNAL_DATA", } DatabaseResourceFeed_FeedType_value = map[string]int32{ "FEEDTYPE_UNSPECIFIED": 0, "RESOURCE_METADATA": 1, "CONFIG_BASED_SIGNAL_DATA": 5, } )
Enum value maps for DatabaseResourceFeed_FeedType.
var ( DatabaseResourceMetadata_State_name = map[int32]string{ 0: "STATE_UNSPECIFIED", 1: "HEALTHY", 2: "UNHEALTHY", 4: "SUSPENDED", 5: "DELETED", 3: "STATE_OTHER", } DatabaseResourceMetadata_State_value = map[string]int32{ "STATE_UNSPECIFIED": 0, "HEALTHY": 1, "UNHEALTHY": 2, "SUSPENDED": 4, "DELETED": 5, "STATE_OTHER": 3, } )
Enum value maps for DatabaseResourceMetadata_State.
var ( BackupRun_Status_name = map[int32]string{ 0: "STATUS_UNSPECIFIED", 1: "SUCCESSFUL", 2: "FAILED", } BackupRun_Status_value = map[string]int32{ "STATUS_UNSPECIFIED": 0, "SUCCESSFUL": 1, "FAILED": 2, } )
Enum value maps for BackupRun_Status.
Functions ¶
This section is empty.
Types ¶
type AvailabilityConfiguration ¶
type AvailabilityConfiguration struct {
// Availability type. Potential values:
// * `ZONAL`: The instance serves data from only one zone. Outages in that
// zone affect data accessibility.
// * `REGIONAL`: The instance can serve data from more than one zone in a
// region (it is highly available).
AvailabilityType AvailabilityType `` /* 182-byte string literal not displayed */
ExternalReplicaConfigured bool `` /* 139-byte string literal not displayed */
PromotableReplicaConfigured bool `` /* 145-byte string literal not displayed */
// Checks for resources that are configured to have redundancy, and ongoing
// replication across regions
CrossRegionReplicaConfigured bool `` /* 150-byte string literal not displayed */
// Checks for existence of (multi-cluster) routing configuration that allows
// automatic failover to a different zone/region in case of an outage.
// Applicable to Bigtable resources.
AutomaticFailoverRoutingConfigured bool `` /* 168-byte string literal not displayed */
// contains filtered or unexported fields
}
Configuration for availability of database instance
func (*AvailabilityConfiguration) Descriptor
deprecated
func (*AvailabilityConfiguration) Descriptor() ([]byte, []int)
Deprecated: Use AvailabilityConfiguration.ProtoReflect.Descriptor instead.
func (*AvailabilityConfiguration) GetAutomaticFailoverRoutingConfigured ¶
func (x *AvailabilityConfiguration) GetAutomaticFailoverRoutingConfigured() bool
func (*AvailabilityConfiguration) GetAvailabilityType ¶
func (x *AvailabilityConfiguration) GetAvailabilityType() AvailabilityType
func (*AvailabilityConfiguration) GetCrossRegionReplicaConfigured ¶
func (x *AvailabilityConfiguration) GetCrossRegionReplicaConfigured() bool
func (*AvailabilityConfiguration) GetExternalReplicaConfigured ¶
func (x *AvailabilityConfiguration) GetExternalReplicaConfigured() bool
func (*AvailabilityConfiguration) GetPromotableReplicaConfigured ¶
func (x *AvailabilityConfiguration) GetPromotableReplicaConfigured() bool
func (*AvailabilityConfiguration) ProtoMessage ¶
func (*AvailabilityConfiguration) ProtoMessage()
func (*AvailabilityConfiguration) ProtoReflect ¶
func (x *AvailabilityConfiguration) ProtoReflect() protoreflect.Message
func (*AvailabilityConfiguration) Reset ¶
func (x *AvailabilityConfiguration) Reset()
func (*AvailabilityConfiguration) String ¶
func (x *AvailabilityConfiguration) String() string
type AvailabilityType ¶
type AvailabilityType int32
The availability type of the given database instance.
const ( AvailabilityType_AVAILABILITY_TYPE_UNSPECIFIED AvailabilityType = 0 // Zonal available instance. AvailabilityType_ZONAL AvailabilityType = 1 // Regional available instance. AvailabilityType_REGIONAL AvailabilityType = 2 // Multi regional instance AvailabilityType_MULTI_REGIONAL AvailabilityType = 3 // For rest of the other category AvailabilityType_AVAILABILITY_TYPE_OTHER AvailabilityType = 4 )
func (AvailabilityType) Descriptor ¶
func (AvailabilityType) Descriptor() protoreflect.EnumDescriptor
func (AvailabilityType) Enum ¶
func (x AvailabilityType) Enum() *AvailabilityType
func (AvailabilityType) EnumDescriptor
deprecated
func (AvailabilityType) EnumDescriptor() ([]byte, []int)
Deprecated: Use AvailabilityType.Descriptor instead.
func (AvailabilityType) Number ¶
func (x AvailabilityType) Number() protoreflect.EnumNumber
func (AvailabilityType) String ¶
func (x AvailabilityType) String() string
func (AvailabilityType) Type ¶
func (AvailabilityType) Type() protoreflect.EnumType
type BackupConfiguration ¶
type BackupConfiguration struct {
// Whether customer visible automated backups are enabled on the instance.
AutomatedBackupEnabled bool `` /* 130-byte string literal not displayed */
// Backup retention settings.
BackupRetentionSettings *RetentionSettings `` /* 132-byte string literal not displayed */
// Whether point-in-time recovery is enabled. This is optional field, if the
// database service does not have this feature or metadata is not available in
// control plane, this can be omitted.
PointInTimeRecoveryEnabled bool `` /* 146-byte string literal not displayed */
// contains filtered or unexported fields
}
Configuration for automatic backups
func (*BackupConfiguration) Descriptor
deprecated
func (*BackupConfiguration) Descriptor() ([]byte, []int)
Deprecated: Use BackupConfiguration.ProtoReflect.Descriptor instead.
func (*BackupConfiguration) GetAutomatedBackupEnabled ¶
func (x *BackupConfiguration) GetAutomatedBackupEnabled() bool
func (*BackupConfiguration) GetBackupRetentionSettings ¶
func (x *BackupConfiguration) GetBackupRetentionSettings() *RetentionSettings
func (*BackupConfiguration) GetPointInTimeRecoveryEnabled ¶
func (x *BackupConfiguration) GetPointInTimeRecoveryEnabled() bool
func (*BackupConfiguration) ProtoMessage ¶
func (*BackupConfiguration) ProtoMessage()
func (*BackupConfiguration) ProtoReflect ¶
func (x *BackupConfiguration) ProtoReflect() protoreflect.Message
func (*BackupConfiguration) Reset ¶
func (x *BackupConfiguration) Reset()
func (*BackupConfiguration) String ¶
func (x *BackupConfiguration) String() string
type BackupRun ¶
type BackupRun struct {
// The time the backup operation started.
// REQUIRED
StartTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=start_time,json=startTime,proto3" json:"start_time,omitempty"`
// The time the backup operation completed.
// REQUIRED
EndTime *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=end_time,json=endTime,proto3" json:"end_time,omitempty"`
// The status of this run.
// REQUIRED
Status BackupRun_Status `` /* 138-byte string literal not displayed */
// contains filtered or unexported fields
}
A backup run.
func (*BackupRun) Descriptor
deprecated
func (*BackupRun) GetEndTime ¶
func (x *BackupRun) GetEndTime() *timestamppb.Timestamp
func (*BackupRun) GetStartTime ¶
func (x *BackupRun) GetStartTime() *timestamppb.Timestamp
func (*BackupRun) GetStatus ¶
func (x *BackupRun) GetStatus() BackupRun_Status
func (*BackupRun) ProtoMessage ¶
func (*BackupRun) ProtoMessage()
func (*BackupRun) ProtoReflect ¶
func (x *BackupRun) ProtoReflect() protoreflect.Message
type BackupRun_Status ¶
type BackupRun_Status int32
The status of a backup run.
const ( BackupRun_STATUS_UNSPECIFIED BackupRun_Status = 0 // The backup was successful. BackupRun_SUCCESSFUL BackupRun_Status = 1 // The backup was unsuccessful. BackupRun_FAILED BackupRun_Status = 2 )
func (BackupRun_Status) Descriptor ¶
func (BackupRun_Status) Descriptor() protoreflect.EnumDescriptor
func (BackupRun_Status) Enum ¶
func (x BackupRun_Status) Enum() *BackupRun_Status
func (BackupRun_Status) EnumDescriptor
deprecated
func (BackupRun_Status) EnumDescriptor() ([]byte, []int)
Deprecated: Use BackupRun_Status.Descriptor instead.
func (BackupRun_Status) Number ¶
func (x BackupRun_Status) Number() protoreflect.EnumNumber
func (BackupRun_Status) String ¶
func (x BackupRun_Status) String() string
func (BackupRun_Status) Type ¶
func (BackupRun_Status) Type() protoreflect.EnumType
type ConfigBasedSignalData ¶
type ConfigBasedSignalData struct {
// Database resource id.
ResourceId *DatabaseResourceId `protobuf:"bytes,1,opt,name=resource_id,json=resourceId,proto3" json:"resource_id,omitempty"`
// Full Resource name of the source resource.
FullResourceName string `protobuf:"bytes,2,opt,name=full_resource_name,json=fullResourceName,proto3" json:"full_resource_name,omitempty"`
// Last time signal was refreshed
LastRefreshTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=last_refresh_time,json=lastRefreshTime,proto3" json:"last_refresh_time,omitempty"`
// Signal type of the signal
SignalType SignalType `` /* 158-byte string literal not displayed */
// Types that are assignable to SignalMetadata:
//
// *ConfigBasedSignalData_SignalBoolValue
SignalMetadata isConfigBasedSignalData_SignalMetadata `protobuf_oneof:"signal_metadata"`
// contains filtered or unexported fields
}
Config based signal data. This is used to send signals to Condor which are based on the DB level configurations. These will be used to send signals for self managed databases.
func (*ConfigBasedSignalData) Descriptor
deprecated
func (*ConfigBasedSignalData) Descriptor() ([]byte, []int)
Deprecated: Use ConfigBasedSignalData.ProtoReflect.Descriptor instead.
func (*ConfigBasedSignalData) GetFullResourceName ¶
func (x *ConfigBasedSignalData) GetFullResourceName() string
func (*ConfigBasedSignalData) GetLastRefreshTime ¶
func (x *ConfigBasedSignalData) GetLastRefreshTime() *timestamppb.Timestamp
func (*ConfigBasedSignalData) GetResourceId ¶
func (x *ConfigBasedSignalData) GetResourceId() *DatabaseResourceId
func (*ConfigBasedSignalData) GetSignalBoolValue ¶
func (x *ConfigBasedSignalData) GetSignalBoolValue() bool
func (*ConfigBasedSignalData) GetSignalMetadata ¶
func (m *ConfigBasedSignalData) GetSignalMetadata() isConfigBasedSignalData_SignalMetadata
func (*ConfigBasedSignalData) GetSignalType ¶
func (x *ConfigBasedSignalData) GetSignalType() SignalType
func (*ConfigBasedSignalData) ProtoMessage ¶
func (*ConfigBasedSignalData) ProtoMessage()
func (*ConfigBasedSignalData) ProtoReflect ¶
func (x *ConfigBasedSignalData) ProtoReflect() protoreflect.Message
func (*ConfigBasedSignalData) Reset ¶
func (x *ConfigBasedSignalData) Reset()
func (*ConfigBasedSignalData) String ¶
func (x *ConfigBasedSignalData) String() string
type ConfigBasedSignalData_SignalBoolValue ¶
type ConfigBasedSignalData_SignalBoolValue struct {
// Signal data for boolean signals.
SignalBoolValue bool `protobuf:"varint,5,opt,name=signal_bool_value,json=signalBoolValue,proto3,oneof"`
}
type DatabaseResourceFeed ¶
type DatabaseResourceFeed struct {
// Timestamp when feed is generated.
FeedTimestamp *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=feed_timestamp,json=feedTimestamp,proto3" json:"feed_timestamp,omitempty"`
// Type feed to be ingested into condor
FeedType DatabaseResourceFeed_FeedType `` /* 171-byte string literal not displayed */
// Types that are assignable to Content:
//
// *DatabaseResourceFeed_ResourceMetadata
// *DatabaseResourceFeed_ConfigBasedSignalData
Content isDatabaseResourceFeed_Content `protobuf_oneof:"Content"`
// contains filtered or unexported fields
}
func (*DatabaseResourceFeed) Descriptor
deprecated
func (*DatabaseResourceFeed) Descriptor() ([]byte, []int)
Deprecated: Use DatabaseResourceFeed.ProtoReflect.Descriptor instead.
func (*DatabaseResourceFeed) GetConfigBasedSignalData ¶
func (x *DatabaseResourceFeed) GetConfigBasedSignalData() *ConfigBasedSignalData
func (*DatabaseResourceFeed) GetContent ¶
func (m *DatabaseResourceFeed) GetContent() isDatabaseResourceFeed_Content
func (*DatabaseResourceFeed) GetFeedTimestamp ¶
func (x *DatabaseResourceFeed) GetFeedTimestamp() *timestamppb.Timestamp
func (*DatabaseResourceFeed) GetFeedType ¶
func (x *DatabaseResourceFeed) GetFeedType() DatabaseResourceFeed_FeedType
func (*DatabaseResourceFeed) GetResourceMetadata ¶
func (x *DatabaseResourceFeed) GetResourceMetadata() *DatabaseResourceMetadata
func (*DatabaseResourceFeed) ProtoMessage ¶
func (*DatabaseResourceFeed) ProtoMessage()
func (*DatabaseResourceFeed) ProtoReflect ¶
func (x *DatabaseResourceFeed) ProtoReflect() protoreflect.Message
func (*DatabaseResourceFeed) Reset ¶
func (x *DatabaseResourceFeed) Reset()
func (*DatabaseResourceFeed) String ¶
func (x *DatabaseResourceFeed) String() string
type DatabaseResourceFeed_ConfigBasedSignalData ¶
type DatabaseResourceFeed_ConfigBasedSignalData struct {
// Config based signal data is used to ingest signals that are generated
// based on the configuration of the database resource.
ConfigBasedSignalData *ConfigBasedSignalData `protobuf:"bytes,8,opt,name=config_based_signal_data,json=configBasedSignalData,proto3,oneof"`
}
type DatabaseResourceFeed_FeedType ¶
type DatabaseResourceFeed_FeedType int32
const ( // Unspecified feed type. DatabaseResourceFeed_FEEDTYPE_UNSPECIFIED DatabaseResourceFeed_FeedType = 0 // Database resource metadata feed from control plane DatabaseResourceFeed_RESOURCE_METADATA DatabaseResourceFeed_FeedType = 1 // Config based signal data feed DatabaseResourceFeed_CONFIG_BASED_SIGNAL_DATA DatabaseResourceFeed_FeedType = 5 )
func (DatabaseResourceFeed_FeedType) Descriptor ¶
func (DatabaseResourceFeed_FeedType) Descriptor() protoreflect.EnumDescriptor
func (DatabaseResourceFeed_FeedType) Enum ¶
func (x DatabaseResourceFeed_FeedType) Enum() *DatabaseResourceFeed_FeedType
func (DatabaseResourceFeed_FeedType) EnumDescriptor
deprecated
func (DatabaseResourceFeed_FeedType) EnumDescriptor() ([]byte, []int)
Deprecated: Use DatabaseResourceFeed_FeedType.Descriptor instead.
func (DatabaseResourceFeed_FeedType) Number ¶
func (x DatabaseResourceFeed_FeedType) Number() protoreflect.EnumNumber
func (DatabaseResourceFeed_FeedType) String ¶
func (x DatabaseResourceFeed_FeedType) String() string
func (DatabaseResourceFeed_FeedType) Type ¶
func (DatabaseResourceFeed_FeedType) Type() protoreflect.EnumType
type DatabaseResourceFeed_ResourceMetadata ¶
type DatabaseResourceFeed_ResourceMetadata struct {
ResourceMetadata *DatabaseResourceMetadata `protobuf:"bytes,4,opt,name=resource_metadata,json=resourceMetadata,proto3,oneof"`
}
type DatabaseResourceId ¶
type DatabaseResourceId struct {
// Cloud provider name. Ex: GCP/AWS/Azure/OnPrem/SelfManaged
Provider DatabaseResourceId_Provider `` /* 153-byte string literal not displayed */
// Needs to be used only when the provider is PROVIDER_OTHER.
ProviderDescription string `protobuf:"bytes,3,opt,name=provider_description,json=providerDescription,proto3" json:"provider_description,omitempty"`
// A service-local token that distinguishes this resource from other resources
// within the same service.
UniqueId string `protobuf:"bytes,2,opt,name=unique_id,json=uniqueId,proto3" json:"unique_id,omitempty"`
// The type of resource this ID is identifying. Ex
// compute.googleapis.com/Instance
// REQUIRED Please refer go/condor-common-datamodel
ResourceType string `protobuf:"bytes,4,opt,name=resource_type,json=resourceType,proto3" json:"resource_type,omitempty"`
// contains filtered or unexported fields
}
DatabaseResourceId will serve as primary key for any resource ingestion event.
func (*DatabaseResourceId) Descriptor
deprecated
func (*DatabaseResourceId) Descriptor() ([]byte, []int)
Deprecated: Use DatabaseResourceId.ProtoReflect.Descriptor instead.
func (*DatabaseResourceId) GetProvider ¶
func (x *DatabaseResourceId) GetProvider() DatabaseResourceId_Provider
func (*DatabaseResourceId) GetProviderDescription ¶
func (x *DatabaseResourceId) GetProviderDescription() string
func (*DatabaseResourceId) GetResourceType ¶
func (x *DatabaseResourceId) GetResourceType() string
func (*DatabaseResourceId) GetUniqueId ¶
func (x *DatabaseResourceId) GetUniqueId() string
func (*DatabaseResourceId) ProtoMessage ¶
func (*DatabaseResourceId) ProtoMessage()
func (*DatabaseResourceId) ProtoReflect ¶
func (x *DatabaseResourceId) ProtoReflect() protoreflect.Message
func (*DatabaseResourceId) Reset ¶
func (x *DatabaseResourceId) Reset()
func (*DatabaseResourceId) String ¶
func (x *DatabaseResourceId) String() string
type DatabaseResourceId_Provider ¶
type DatabaseResourceId_Provider int32
const ( DatabaseResourceId_PROVIDER_UNSPECIFIED DatabaseResourceId_Provider = 0 // Google cloud platform provider DatabaseResourceId_GCP DatabaseResourceId_Provider = 1 // Amazon web service DatabaseResourceId_AWS DatabaseResourceId_Provider = 2 // Azure web service DatabaseResourceId_AZURE DatabaseResourceId_Provider = 3 // On-prem database resources. DatabaseResourceId_ONPREM DatabaseResourceId_Provider = 4 // Self-managed database provider. // These are resources on a cloud platform, // e.g., database resource installed in a GCE VM, // but not a managed database service. DatabaseResourceId_SELFMANAGED DatabaseResourceId_Provider = 5 // For the rest of the other categories. // Other refers to the rest of other database service providers, this could // be smaller cloud provider. This needs to be provided when the provider is // known, but it is not present in the existing set of enum values. DatabaseResourceId_PROVIDER_OTHER DatabaseResourceId_Provider = 6 )
func (DatabaseResourceId_Provider) Descriptor ¶
func (DatabaseResourceId_Provider) Descriptor() protoreflect.EnumDescriptor
func (DatabaseResourceId_Provider) Enum ¶
func (x DatabaseResourceId_Provider) Enum() *DatabaseResourceId_Provider
func (DatabaseResourceId_Provider) EnumDescriptor
deprecated
func (DatabaseResourceId_Provider) EnumDescriptor() ([]byte, []int)
Deprecated: Use DatabaseResourceId_Provider.Descriptor instead.
func (DatabaseResourceId_Provider) Number ¶
func (x DatabaseResourceId_Provider) Number() protoreflect.EnumNumber
func (DatabaseResourceId_Provider) String ¶
func (x DatabaseResourceId_Provider) String() string
func (DatabaseResourceId_Provider) Type ¶
func (DatabaseResourceId_Provider) Type() protoreflect.EnumType
type DatabaseResourceMetadata ¶
type DatabaseResourceMetadata struct {
// Unique identifier for a Database resource
Id *DatabaseResourceId `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// Different from DatabaseResourceId.unique_id, a resource name can be reused
// over time. That is, after a resource named "ABC" is deleted, the name "ABC"
// can be used to to create a new resource within the same source. Resource
// name to follow CAIS resource_name format as noted here
// go/condor-common-datamodel
ResourceName string `protobuf:"bytes,2,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
// Identifier for this resource's immediate parent/primary resource if the
// current resource is a replica or derived form of another Database resource.
// Else it would be NULL.
// REQUIRED if the immediate parent exists when first time resource is getting
// ingested, otherwise optional.
PrimaryResourceId *DatabaseResourceId `protobuf:"bytes,3,opt,name=primary_resource_id,json=primaryResourceId,proto3" json:"primary_resource_id,omitempty"`
// Primary resource location.
// REQUIRED if the immediate parent exists when first time resource is getting
// ingested, otherwise optional.
PrimaryResourceLocation string `` /* 133-byte string literal not displayed */
// Closest parent Cloud Resource Manager container of
// this resource. It must be resource name of a Cloud Resource Manager
// project with the format of "<type>/<number>", such as
// "projects/123".
// For GCP provided resources, number should be project number.
ResourceContainer string `protobuf:"bytes,4,opt,name=resource_container,json=resourceContainer,proto3" json:"resource_container,omitempty"`
// The resource location.
// REQUIRED
Location string `protobuf:"bytes,5,opt,name=location,proto3" json:"location,omitempty"`
// The creation time of the resource, i.e. the time when resource is created
// and recorded in partner service.
CreationTime *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=creation_time,json=creationTime,proto3" json:"creation_time,omitempty"`
// The time at which the resource was updated and recorded at partner service.
UpdationTime *timestamppb.Timestamp `protobuf:"bytes,7,opt,name=updation_time,json=updationTime,proto3" json:"updation_time,omitempty"`
// The state that the instance is expected to be in. For example, an instance
// state can transition to UNHEALTHY due to wrong patch update, while the
// expected state will remain at the HEALTHY.
ExpectedState DatabaseResourceMetadata_State `` /* 187-byte string literal not displayed */
// Current state of the instance.
CurrentState DatabaseResourceMetadata_State `` /* 184-byte string literal not displayed */
// The type of the instance. Specified at creation time.
InstanceType InstanceType `` /* 167-byte string literal not displayed */
// The product this resource represents.
Product *Product `protobuf:"bytes,11,opt,name=product,proto3" json:"product,omitempty"`
// Availability configuration for this instance
AvailabilityConfiguration *AvailabilityConfiguration `` /* 137-byte string literal not displayed */
// Backup configuration for this instance
BackupConfiguration *BackupConfiguration `protobuf:"bytes,14,opt,name=backup_configuration,json=backupConfiguration,proto3" json:"backup_configuration,omitempty"`
// Latest backup run information for this instance
BackupRun *BackupRun `protobuf:"bytes,15,opt,name=backup_run,json=backupRun,proto3" json:"backup_run,omitempty"`
// User-provided labels associated with the resource
UserLabelSet *UserLabels `protobuf:"bytes,18,opt,name=user_label_set,json=userLabelSet,proto3" json:"user_label_set,omitempty"`
// Machine configuration for this resource.
MachineConfiguration *MachineConfiguration `protobuf:"bytes,19,opt,name=machine_configuration,json=machineConfiguration,proto3" json:"machine_configuration,omitempty"`
// Tags associated with this resources.
TagsSet *Tags `protobuf:"bytes,20,opt,name=tags_set,json=tagsSet,proto3" json:"tags_set,omitempty"`
// contains filtered or unexported fields
}
Common model for database resource instance metadata. Next ID: 25
func (*DatabaseResourceMetadata) Descriptor
deprecated
func (*DatabaseResourceMetadata) Descriptor() ([]byte, []int)
Deprecated: Use DatabaseResourceMetadata.ProtoReflect.Descriptor instead.
func (*DatabaseResourceMetadata) GetAvailabilityConfiguration ¶
func (x *DatabaseResourceMetadata) GetAvailabilityConfiguration() *AvailabilityConfiguration
func (*DatabaseResourceMetadata) GetBackupConfiguration ¶
func (x *DatabaseResourceMetadata) GetBackupConfiguration() *BackupConfiguration
func (*DatabaseResourceMetadata) GetBackupRun ¶
func (x *DatabaseResourceMetadata) GetBackupRun() *BackupRun
func (*DatabaseResourceMetadata) GetCreationTime ¶
func (x *DatabaseResourceMetadata) GetCreationTime() *timestamppb.Timestamp
func (*DatabaseResourceMetadata) GetCurrentState ¶
func (x *DatabaseResourceMetadata) GetCurrentState() DatabaseResourceMetadata_State
func (*DatabaseResourceMetadata) GetExpectedState ¶
func (x *DatabaseResourceMetadata) GetExpectedState() DatabaseResourceMetadata_State
func (*DatabaseResourceMetadata) GetId ¶
func (x *DatabaseResourceMetadata) GetId() *DatabaseResourceId
func (*DatabaseResourceMetadata) GetInstanceType ¶
func (x *DatabaseResourceMetadata) GetInstanceType() InstanceType
func (*DatabaseResourceMetadata) GetLocation ¶
func (x *DatabaseResourceMetadata) GetLocation() string
func (*DatabaseResourceMetadata) GetMachineConfiguration ¶
func (x *DatabaseResourceMetadata) GetMachineConfiguration() *MachineConfiguration
func (*DatabaseResourceMetadata) GetPrimaryResourceId ¶
func (x *DatabaseResourceMetadata) GetPrimaryResourceId() *DatabaseResourceId
func (*DatabaseResourceMetadata) GetPrimaryResourceLocation ¶
func (x *DatabaseResourceMetadata) GetPrimaryResourceLocation() string
func (*DatabaseResourceMetadata) GetProduct ¶
func (x *DatabaseResourceMetadata) GetProduct() *Product
func (*DatabaseResourceMetadata) GetResourceContainer ¶
func (x *DatabaseResourceMetadata) GetResourceContainer() string
func (*DatabaseResourceMetadata) GetResourceName ¶
func (x *DatabaseResourceMetadata) GetResourceName() string
func (*DatabaseResourceMetadata) GetTagsSet ¶
func (x *DatabaseResourceMetadata) GetTagsSet() *Tags
func (*DatabaseResourceMetadata) GetUpdationTime ¶
func (x *DatabaseResourceMetadata) GetUpdationTime() *timestamppb.Timestamp
func (*DatabaseResourceMetadata) GetUserLabelSet ¶
func (x *DatabaseResourceMetadata) GetUserLabelSet() *UserLabels
func (*DatabaseResourceMetadata) ProtoMessage ¶
func (*DatabaseResourceMetadata) ProtoMessage()
func (*DatabaseResourceMetadata) ProtoReflect ¶
func (x *DatabaseResourceMetadata) ProtoReflect() protoreflect.Message
func (*DatabaseResourceMetadata) Reset ¶
func (x *DatabaseResourceMetadata) Reset()
func (*DatabaseResourceMetadata) String ¶
func (x *DatabaseResourceMetadata) String() string
type DatabaseResourceMetadata_State ¶
type DatabaseResourceMetadata_State int32
const ( DatabaseResourceMetadata_STATE_UNSPECIFIED DatabaseResourceMetadata_State = 0 // The instance is running. DatabaseResourceMetadata_HEALTHY DatabaseResourceMetadata_State = 1 // Instance being created, updated, deleted or under maintenance DatabaseResourceMetadata_UNHEALTHY DatabaseResourceMetadata_State = 2 // When instance is suspended DatabaseResourceMetadata_SUSPENDED DatabaseResourceMetadata_State = 4 // Instance is deleted. DatabaseResourceMetadata_DELETED DatabaseResourceMetadata_State = 5 // For rest of the other category DatabaseResourceMetadata_STATE_OTHER DatabaseResourceMetadata_State = 3 )
func (DatabaseResourceMetadata_State) Descriptor ¶
func (DatabaseResourceMetadata_State) Descriptor() protoreflect.EnumDescriptor
func (DatabaseResourceMetadata_State) Enum ¶
func (x DatabaseResourceMetadata_State) Enum() *DatabaseResourceMetadata_State
func (DatabaseResourceMetadata_State) EnumDescriptor
deprecated
func (DatabaseResourceMetadata_State) EnumDescriptor() ([]byte, []int)
Deprecated: Use DatabaseResourceMetadata_State.Descriptor instead.
func (DatabaseResourceMetadata_State) Number ¶
func (x DatabaseResourceMetadata_State) Number() protoreflect.EnumNumber
func (DatabaseResourceMetadata_State) String ¶
func (x DatabaseResourceMetadata_State) String() string
func (DatabaseResourceMetadata_State) Type ¶
func (DatabaseResourceMetadata_State) Type() protoreflect.EnumType
type Engine ¶
type Engine int32
Engine refers to underlying database binary running in an instance.
const ( // UNSPECIFIED means engine type is not known or available. Engine_ENGINE_UNSPECIFIED Engine = 0 // MySQL binary running as an engine in the database instance. Engine_ENGINE_MYSQL Engine = 1 // Postgres binary running as engine in database instance. Engine_ENGINE_POSTGRES Engine = 2 // SQLServer binary running as engine in database instance. Engine_ENGINE_SQL_SERVER Engine = 3 // Native database binary running as engine in instance. Engine_ENGINE_NATIVE Engine = 4 // Oracle Exadata engine. Engine_ENGINE_EXADATA_ORACLE Engine = 12 // Oracle Autonomous DB Serverless engine. Engine_ENGINE_ADB_SERVERLESS_ORACLE Engine = 13 // Other refers to rest of other database engine. This is to be when engine is // known, but it is not present in this enum. Engine_ENGINE_OTHER Engine = 6 )
func (Engine) Descriptor ¶
func (Engine) Descriptor() protoreflect.EnumDescriptor
func (Engine) EnumDescriptor
deprecated
func (Engine) Number ¶
func (x Engine) Number() protoreflect.EnumNumber
func (Engine) Type ¶
func (Engine) Type() protoreflect.EnumType
type GCBDRConfiguration ¶
type GCBDRConfiguration struct {
// Whether the resource is managed by GCBDR.
GcbdrManaged bool `protobuf:"varint,1,opt,name=gcbdr_managed,json=gcbdrManaged,proto3" json:"gcbdr_managed,omitempty"`
// contains filtered or unexported fields
}
GCBDR Configuration for the resource. (-- api-linter: core::0140::abbreviations=disabled
aip.dev/not-precedent: This is required for consistency with the existing configuration fields defined in the proto. --)
func (*GCBDRConfiguration) Descriptor
deprecated
func (*GCBDRConfiguration) Descriptor() ([]byte, []int)
Deprecated: Use GCBDRConfiguration.ProtoReflect.Descriptor instead.
func (*GCBDRConfiguration) GetGcbdrManaged ¶
func (x *GCBDRConfiguration) GetGcbdrManaged() bool
func (*GCBDRConfiguration) ProtoMessage ¶
func (*GCBDRConfiguration) ProtoMessage()
func (*GCBDRConfiguration) ProtoReflect ¶
func (x *GCBDRConfiguration) ProtoReflect() protoreflect.Message
func (*GCBDRConfiguration) Reset ¶
func (x *GCBDRConfiguration) Reset()
func (*GCBDRConfiguration) String ¶
func (x *GCBDRConfiguration) String() string
type InstanceType ¶
type InstanceType int32
InstanceType refers to type of database resource instance. Next ID: 11
const ( // Unspecified. // // Deprecated: Marked as deprecated in sharedprotos/databasecenter/databasecenter.proto. InstanceType_INSTANCE_TYPE_UNSPECIFIED InstanceType = 0 // For rest of the other categories. InstanceType_SUB_RESOURCE_TYPE_UNSPECIFIED InstanceType = 9 // A regular primary database instance. InstanceType_SUB_RESOURCE_TYPE_PRIMARY InstanceType = 5 // A cluster or an instance acting as a secondary. InstanceType_SUB_RESOURCE_TYPE_SECONDARY InstanceType = 6 // An instance acting as a read-replica. InstanceType_SUB_RESOURCE_TYPE_READ_REPLICA InstanceType = 7 // An instance acting as an external primary. InstanceType_SUB_RESOURCE_TYPE_EXTERNAL_PRIMARY InstanceType = 10 // For rest of the other categories. InstanceType_SUB_RESOURCE_TYPE_OTHER InstanceType = 8 )
func (InstanceType) Descriptor ¶
func (InstanceType) Descriptor() protoreflect.EnumDescriptor
func (InstanceType) Enum ¶
func (x InstanceType) Enum() *InstanceType
func (InstanceType) EnumDescriptor
deprecated
func (InstanceType) EnumDescriptor() ([]byte, []int)
Deprecated: Use InstanceType.Descriptor instead.
func (InstanceType) Number ¶
func (x InstanceType) Number() protoreflect.EnumNumber
func (InstanceType) String ¶
func (x InstanceType) String() string
func (InstanceType) Type ¶
func (InstanceType) Type() protoreflect.EnumType
type MachineConfiguration ¶
type MachineConfiguration struct {
// Memory size in bytes.
MemorySizeInBytes int64 `protobuf:"varint,2,opt,name=memory_size_in_bytes,json=memorySizeInBytes,proto3" json:"memory_size_in_bytes,omitempty"`
// Number of shards (if applicable).
ShardCount int32 `protobuf:"varint,3,opt,name=shard_count,json=shardCount,proto3" json:"shard_count,omitempty"`
// The number of vCPUs.
VcpuCount float64 `protobuf:"fixed64,4,opt,name=vcpu_count,json=vcpuCount,proto3" json:"vcpu_count,omitempty"`
// contains filtered or unexported fields
}
MachineConfiguration describes the configuration of a machine specific to Database Resource.
func (*MachineConfiguration) Descriptor
deprecated
func (*MachineConfiguration) Descriptor() ([]byte, []int)
Deprecated: Use MachineConfiguration.ProtoReflect.Descriptor instead.
func (*MachineConfiguration) GetMemorySizeInBytes ¶
func (x *MachineConfiguration) GetMemorySizeInBytes() int64
func (*MachineConfiguration) GetShardCount ¶
func (x *MachineConfiguration) GetShardCount() int32
func (*MachineConfiguration) GetVcpuCount ¶
func (x *MachineConfiguration) GetVcpuCount() float64
func (*MachineConfiguration) ProtoMessage ¶
func (*MachineConfiguration) ProtoMessage()
func (*MachineConfiguration) ProtoReflect ¶
func (x *MachineConfiguration) ProtoReflect() protoreflect.Message
func (*MachineConfiguration) Reset ¶
func (x *MachineConfiguration) Reset()
func (*MachineConfiguration) String ¶
func (x *MachineConfiguration) String() string
type Product ¶
type Product struct {
// Type of specific database product. It could be CloudSQL, AlloyDB etc..
Type ProductType `` /* 129-byte string literal not displayed */
// The specific engine that the underlying database is running.
Engine Engine `` /* 128-byte string literal not displayed */
// Version of the underlying database engine. Example values: For MySQL, it
// could be "8.0", "5.7" etc.. For Postgres, it could be "14", "15" etc..
Version string `protobuf:"bytes,3,opt,name=version,proto3" json:"version,omitempty"`
// Minor version of the underlying database engine. Example values: For MySQL,
// it could be "8.0.32", "5.7.32" etc.. For Postgres, it could be "14.3",
// "15.3" etc..
MinorVersion string `protobuf:"bytes,4,opt,name=minor_version,json=minorVersion,proto3" json:"minor_version,omitempty"`
// contains filtered or unexported fields
}
Product specification for Condor resources.
func (*Product) Descriptor
deprecated
func (*Product) GetMinorVersion ¶
func (*Product) GetType ¶
func (x *Product) GetType() ProductType
func (*Product) GetVersion ¶
func (*Product) ProtoMessage ¶
func (*Product) ProtoMessage()
func (*Product) ProtoReflect ¶
func (x *Product) ProtoReflect() protoreflect.Message
type ProductType ¶
type ProductType int32
ProductType is used to identify a database service offering either in a cloud provider or on-premise. This enum needs to be updated whenever we introduce a new ProductType.
const ( // UNSPECIFIED means product type is not known or available. ProductType_PRODUCT_TYPE_UNSPECIFIED ProductType = 0 // On-premise product area ProductType_PRODUCT_TYPE_ON_PREM ProductType = 4 // Other refers to rest of other product type. This is to be when product type // is known, but it is not present in this enum. ProductType_PRODUCT_TYPE_OTHER ProductType = 5 // Compute Engine self managed databases ProductType_PRODUCT_TYPE_COMPUTE_ENGINE ProductType = 9 // Oracle product area in GCP ProductType_PRODUCT_TYPE_ORACLE_ON_GCP ProductType = 10 )
func (ProductType) Descriptor ¶
func (ProductType) Descriptor() protoreflect.EnumDescriptor
func (ProductType) Enum ¶
func (x ProductType) Enum() *ProductType
func (ProductType) EnumDescriptor
deprecated
func (ProductType) EnumDescriptor() ([]byte, []int)
Deprecated: Use ProductType.Descriptor instead.
func (ProductType) Number ¶
func (x ProductType) Number() protoreflect.EnumNumber
func (ProductType) String ¶
func (x ProductType) String() string
func (ProductType) Type ¶
func (ProductType) Type() protoreflect.EnumType
type RetentionSettings ¶
type RetentionSettings struct {
// Depending on the value of retention_unit, this is used to determine
// if a backup needs to be deleted. If retention_unit is 'COUNT', we will
// retain this many backups.
//
// Types that are assignable to Retention:
//
// *RetentionSettings_QuantityBasedRetention
// *RetentionSettings_DurationBasedRetention
// *RetentionSettings_TimestampBasedRetentionTime
Retention isRetentionSettings_Retention `protobuf_oneof:"retention"`
// contains filtered or unexported fields
}
func (*RetentionSettings) Descriptor
deprecated
func (*RetentionSettings) Descriptor() ([]byte, []int)
Deprecated: Use RetentionSettings.ProtoReflect.Descriptor instead.
func (*RetentionSettings) GetDurationBasedRetention ¶
func (x *RetentionSettings) GetDurationBasedRetention() *durationpb.Duration
func (*RetentionSettings) GetQuantityBasedRetention ¶
func (x *RetentionSettings) GetQuantityBasedRetention() *wrapperspb.Int32Value
func (*RetentionSettings) GetRetention ¶
func (m *RetentionSettings) GetRetention() isRetentionSettings_Retention
func (*RetentionSettings) GetTimestampBasedRetentionTime ¶
func (x *RetentionSettings) GetTimestampBasedRetentionTime() *timestamppb.Timestamp
func (*RetentionSettings) ProtoMessage ¶
func (*RetentionSettings) ProtoMessage()
func (*RetentionSettings) ProtoReflect ¶
func (x *RetentionSettings) ProtoReflect() protoreflect.Message
func (*RetentionSettings) Reset ¶
func (x *RetentionSettings) Reset()
func (*RetentionSettings) String ¶
func (x *RetentionSettings) String() string
type RetentionSettings_DurationBasedRetention ¶
type RetentionSettings_DurationBasedRetention struct {
// Duration based retention period i.e. 172800 seconds (2 days)
DurationBasedRetention *durationpb.Duration `protobuf:"bytes,4,opt,name=duration_based_retention,json=durationBasedRetention,proto3,oneof"`
}
type RetentionSettings_QuantityBasedRetention ¶
type RetentionSettings_QuantityBasedRetention struct {
QuantityBasedRetention *wrapperspb.Int32Value `protobuf:"bytes,3,opt,name=quantity_based_retention,json=quantityBasedRetention,proto3,oneof"`
}
type RetentionSettings_TimestampBasedRetentionTime ¶
type RetentionSettings_TimestampBasedRetentionTime struct {
// Timestamp based retention period i.e. 2024-05-01T00:00:00Z
TimestampBasedRetentionTime *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=timestamp_based_retention_time,json=timestampBasedRetentionTime,proto3,oneof"`
}
type SignalType ¶
type SignalType int32
Signal type
const ( // Unspecified signal type. SignalType_SIGNAL_TYPE_UNSPECIFIED SignalType = 0 // Outdated Minor Version SignalType_SIGNAL_TYPE_OUTDATED_MINOR_VERSION SignalType = 1 // Represents database auditing is disabled. SignalType_SIGNAL_TYPE_DATABASE_AUDITING_DISABLED SignalType = 2 // Represents if a database has a password configured for the // root account or not. SignalType_SIGNAL_TYPE_NO_ROOT_PASSWORD SignalType = 3 // Represents if a resource is exposed to public access. SignalType_SIGNAL_TYPE_EXPOSED_TO_PUBLIC_ACCESS SignalType = 4 // Represents if a resources requires all incoming connections to use SSL // or not. SignalType_SIGNAL_TYPE_UNENCRYPTED_CONNECTIONS SignalType = 5 )
func (SignalType) Descriptor ¶
func (SignalType) Descriptor() protoreflect.EnumDescriptor
func (SignalType) Enum ¶
func (x SignalType) Enum() *SignalType
func (SignalType) EnumDescriptor
deprecated
func (SignalType) EnumDescriptor() ([]byte, []int)
Deprecated: Use SignalType.Descriptor instead.
func (SignalType) Number ¶
func (x SignalType) Number() protoreflect.EnumNumber
func (SignalType) String ¶
func (x SignalType) String() string
func (SignalType) Type ¶
func (SignalType) Type() protoreflect.EnumType
type Tags ¶
type Tags struct {
// The Tag key/value mappings.
Tags map[string]string `` /* 149-byte string literal not displayed */
// contains filtered or unexported fields
}
Message type for storing tags. Tags provide a way to create annotations for resources, and in some cases conditionally allow or deny policies based on whether a resource has a specific tag.
func (*Tags) Descriptor
deprecated
func (*Tags) ProtoMessage ¶
func (*Tags) ProtoMessage()
func (*Tags) ProtoReflect ¶
func (x *Tags) ProtoReflect() protoreflect.Message
type UserLabels ¶
type UserLabels struct {
Labels map[string]string `` /* 153-byte string literal not displayed */
// contains filtered or unexported fields
}
Message type for storing user labels. User labels are used to tag App Engine resources, allowing users to search for resources matching a set of labels and to aggregate usage data by labels.
func (*UserLabels) Descriptor
deprecated
func (*UserLabels) Descriptor() ([]byte, []int)
Deprecated: Use UserLabels.ProtoReflect.Descriptor instead.
func (*UserLabels) GetLabels ¶
func (x *UserLabels) GetLabels() map[string]string
func (*UserLabels) ProtoMessage ¶
func (*UserLabels) ProtoMessage()
func (*UserLabels) ProtoReflect ¶
func (x *UserLabels) ProtoReflect() protoreflect.Message
func (*UserLabels) Reset ¶
func (x *UserLabels) Reset()
func (*UserLabels) String ¶
func (x *UserLabels) String() string